# TODO:
# - xpmem support (--enable-xpmem, https://github.com/hpc/xpmem)
# - cuda support
# - level_zero (--with-ze, https://github.com/oneapi-src/level-zero + libdrm-devel)
# - AWS Neuron (--with-neuron, nrt/nrt.h)
# - SynapseAI (--with-synapseai, habanalabs/synapse_api.h)
# - lttng (--with-lttng, BR: lttng-ust-devel)
# - gdrcopy (https://github.com/NVIDIA/gdrcopy, requires cuda)
# - rocr (https://github.com/RadeonOpenCompute/ROCR-Runtime)
# - proprietary providers (cray/gni...)
# - bgq (hwi/include/bqc/MU_Descriptor.h)
# - psm2 (https://github.com/cornelisnetworks/opa-psm2)
#
# Conditional build:
%bcond_without	opx	# OPX provider
%bcond_with	psm	# PSM (infinipath-psm) provider
%bcond_without	psm3	# PSM3 provider
#
%ifnarch %{x8664} aarch64
# structures are full of assumptions about 64-bit [u]intptr_t and size_t
%undefine	with_opx
%endif
%ifnarch %{ix86} %{x8664}
%undefine	with_psm
%endif
%ifnarch %{x8664} x32
%undefine	with_psm3
%endif
Summary:	User-space RDMA Fabric interface library
Summary(pl.UTF-8):	Biblioteka interfejsu przestrzeni użytkownika RDMA Fabric
Name:		libfabric
Version:	1.20.1
Release:	1
License:	BSD or GPL v2
Group:		Libraries
#Source0Download: https://github.com/ofiwg/libfabric/releases
Source0:	https://github.com/ofiwg/libfabric/releases/download/v%{version}/%{name}-%{version}.tar.bz2
# Source0-md5:	b60abb57665bdd583bfaedb4a9e859e8
URL:		https://github.com/ofiwg/libfabric
BuildRequires:	autoconf >= 2.60
BuildRequires:	automake >= 1:1.11
%{?with_psm:BuildRequires:	infinipath-psm-devel >= 3.1}
# for efa, psm3, usnic, verbs
BuildRequires:	libibverbs-devel
# for usnic
BuildRequires:	libnl-devel >= 3.2
# for verbs
BuildRequires:	librdmacm-devel
BuildRequires:	libtool >= 2:2
BuildRequires:	liburing-devel >= 2.1
%if %{with opx} || %{with psm3}
BuildRequires:	libuuid-devel
%endif
%if %{with psm3}
# for psm2, psm3
BuildRequires:	numactl-devel
%endif
Conflicts:	fabtests < 1.1.1
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA.

%description -l pl.UTF-8
libfabric dostarcza API przestrzeni użytkownika pozwalające na dostęp
do wysoko wydajnych usług sieci typu fabric, takich jak RDMA.

%package devel
Summary:	Development files for libfabric library
Summary(pl.UTF-8):	Pliki programistyczne biblioteki libfabric
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libibverbs-devel
Requires:	libnl-devel >= 3.2
Requires:	librdmacm-devel

%description devel
Header files for libfabric library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libfabric.

%package static
Summary:	Static libfabric library
Summary(pl.UTF-8):	Statyczna biblioteka libfabric
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libfabric library.

%description static -l pl.UTF-8
Statyczna biblioteka libfabric.

%prep
%setup -q

%build
%{__libtoolize}
%{__aclocal} -I config
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{!?with_opx:--disable-opx} \
	%{!?with_psm:--disable-psm} \
	%{!?with_psm3:--disable-psm3} \
	--disable-silent-rules
%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libfabric.la

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS.md README
%attr(755,root,root) %{_bindir}/fi_info
%attr(755,root,root) %{_bindir}/fi_pingpong
%attr(755,root,root) %{_bindir}/fi_strerror
%attr(755,root,root) %{_libdir}/libfabric.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libfabric.so.1
%{_mandir}/man1/fi_info.1*
%{_mandir}/man1/fi_pingpong.1*
%{_mandir}/man1/fi_strerror.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libfabric.so
%{_includedir}/rdma/fabric.h
%{_includedir}/rdma/fi_*.h
%{_includedir}/rdma/providers
%{_pkgconfigdir}/libfabric.pc
%{_mandir}/man3/fi_*.3*
%{_mandir}/man7/fabric.7*
%{_mandir}/man7/fi_*.7*

%files static
%defattr(644,root,root,755)
%{_libdir}/libfabric.a
%changelog
* Sun Mar 24 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libfabric.git;a=log;h=master

* Sat Mar 23 2024 Jakub Bogusz <qboosh@pld-linux.org> 8930a9f
- updated to 1.20.1

* Fri Jun 10 2022 Jakub Bogusz <qboosh@pld-linux.org> f23fdbc
- more dependencies and bconds

* Fri Jun 10 2022 Jakub Bogusz <qboosh@pld-linux.org> 56f4177
- updated to 1.15.1; disable opx provider on non-LP64 archs

* Sat Feb 19 2022 Jakub Bogusz <qboosh@pld-linux.org> 95834fd
- updated to 1.14.0
- removed obsolete cpu,sh patches

* Thu Apr 25 2019 Jakub Bogusz <qboosh@pld-linux.org> 4ec6c5b
- updated to 1.7.1

* Thu Dec 13 2018 Jakub Bogusz <qboosh@pld-linux.org> 1cbe203
- updated to 1.6.2
- updated cpu patch

* Sat Apr 28 2018 Jakub Bogusz <qboosh@pld-linux.org> 473a21b
- updated to 1.6.0
- added cpu patch (take CPU from configure host_cpu, not uname -p)

* Sat Apr 15 2017 Jakub Bogusz <qboosh@pld-linux.org> 65414b4
- updated to 1.4.1
- updated sh patch

* Mon Apr 18 2016 Jakub Bogusz <qboosh@pld-linux.org> 3fbfeaf
- new Source URL, updated to 1.3.0
- updated sh patch

* Sat Jan 09 2016 Jakub Bogusz <qboosh@pld-linux.org> 1a29f38
- updated to 1.2.0
- added sh patch (fixes build with POSIX sh without bash extensions)

* Sun Nov 01 2015 Jakub Bogusz <qboosh@pld-linux.org> df5b823
- Conflicts: old fabtests (because of fi_info); release 2

* Sun Nov 01 2015 Jakub Bogusz <qboosh@pld-linux.org> e42806a
- updated to 1.1.1
- removed obsolete missing patch

* Tue Jun 16 2015 Jakub Bogusz <qboosh@pld-linux.org> 3e19991
- updated to 1.0.0 release
- updated missing patch

* Sat Feb 21 2015 Jakub Bogusz <qboosh@pld-linux.org> 349e26f
- up to 1.0.0rc2, mark subver in release

* Sat Feb 21 2015 Jakub Bogusz <qboosh@pld-linux.org> 1db96c9
- initial

